from .calculator import percentage, grade
from .attendance import attendance_percentage, is_eligible
from .cgpa import cgpa, cgpa_to_percentage
from .analysis import class_average, topper, fail_count

__all__ = [
    "percentage",
    "grade",
    "attendance_percentage",
    "is_eligible",
    "cgpa",
    "cgpa_to_percentage",
    "class_average",
    "topper",
    "fail_count",
]
